@@ -48,6 +48,11 @@ def default_append_git_suffix_domains() -> list[str]:
     return ["github.com", "gitlab.com"]
 
 
+class EnterpriseFeatures(str, Enum):
+    PROPOSED_CHANGE_REQUIRE_APPROVAL = "proposed_change_require_approval"
+    REVOKE_PROPOSED_CHANGE_APPROVALS = "revoke_proposed_change_approvals"
+
+
 class UserInfoMethod(str, Enum):
     POST = "post"
     GET = "get"
@@ -316,9 +321,15 @@ class DevelopmentSettings(BaseSettings):
         default=False,
         description="Indicates of the frontend should be responsible for the SSO redirection",
     )
+    allow_enterprise_configuration: bool = Field(
+        default=False,
+        description="Allow enterprise configuration in development mode, this will not enable the features just allow the configuration.",
+    )
 
 
 class BrokerSettings(BaseSettings):
+    """Configuration settings for the message bus."""
+
     model_config = SettingsConfigDict(env_prefix="INFRAHUB_BROKER_")
     enable: bool = True
     tls_enabled: bool = Field(default=False, description="Indicates if TLS is enabled for the connection")
@@ -432,9 +443,7 @@ class GitSettings(BaseSettings):
 
 
 class HTTPSettings(BaseSettings):
-    """The HTTP settings control how Infrahub interacts with external HTTP servers
-
-    This can be things like webhooks and OAuth2 providers"""
+    """The HTTP settings control how Infrahub interacts with external HTTP servers. This can be things like webhooks and OAuth2 providers."""
 
     model_config = SettingsConfigDict(env_prefix="INFRAHUB_HTTP_")
     timeout: int = Field(default=10, description="Default connection timeout in seconds")
@@ -638,7 +647,10 @@ class AnalyticsSettings(BaseSettings):
 class ExperimentalFeaturesSettings(BaseSettings):
     model_config = SettingsConfigDict(env_prefix="INFRAHUB_EXPERIMENTAL_")
     graphql_enums: bool = False
-    value_db_index: bool = False
+    value_db_index: bool = Field(
+        default=False,
+        deprecated="This setting has no effect and will be removed in a future version.",
+    )
 
 
 class SecuritySettings(BaseSettings):
@@ -655,7 +667,7 @@ class SecuritySettings(BaseSettings):
     oidc_providers: list[OIDCProvider] = Field(default_factory=list, description="The selected OIDC providers")
     oidc_provider_settings: SecurityOIDCProviderSettings = Field(default_factory=SecurityOIDCProviderSettings)
     restrict_untrusted_jinja2_filters: bool = Field(
-        default=True, description="Indicates if untrusted Jinja2 filters should be disallowd for computed attributes"
+        default=True, description="Indicates if untrusted Jinja2 filters should be disallowed for computed attributes"
     )
     _oauth2_settings: dict[str, SecurityOAuth2Settings] = PrivateAttr(default_factory=dict)
     _oidc_settings: dict[str, SecurityOIDCSettings] = PrivateAttr(default_factory=dict)
@@ -766,6 +778,30 @@ class TraceSettings(BaseSettings):
     exporter_endpoint: str | None = Field(default=None, description="OTLP endpoint for exporting traces")
 
 
+class PolicySettings(BaseSettings):
+    model_config = SettingsConfigDict(env_prefix="INFRAHUB_POLICY_")
+    required_proposed_change_approvals: int = Field(
+        default=0,
+        ge=0,
+        description="Number of approvals required for proposed changes. (Enterprise only: not available in the community version.)",
+    )
+    revoke_proposed_change_approvals: bool = Field(
+        default=False,
+        description="Boolean indicating whether performing changes on a proposed change branch should revoke existing approvals."
+        " (Enterprise only: not available in the community version.)",
+    )
+
+    @property
+    def enterprise_features(self) -> list[EnterpriseFeatures]:
+        """Returns a list of enterprise features that are enabled based on the settings."""
+        features = []
+        if self.required_proposed_change_approvals > 0:
+            features.append(EnterpriseFeatures.PROPOSED_CHANGE_REQUIRE_APPROVAL)
+        if self.revoke_proposed_change_approvals:
+            features.append(EnterpriseFeatures.REVOKE_PROPOSED_CHANGE_APPROVALS)
+        return features
+
+
 @dataclass
 class Override:
     message_bus: InfrahubMessageBus | None = None
@@ -857,6 +893,10 @@ class ConfiguredSettings:
     def analytics(self) -> AnalyticsSettings:
         return self.active_settings.analytics
 
+    @property
+    def policy(self) -> PolicySettings:
+        return self.active_settings.policy
+
     @property
     def security(self) -> SecuritySettings:
         return self.active_settings.security
@@ -873,6 +913,11 @@ class ConfiguredSettings:
     def experimental_features(self) -> ExperimentalFeaturesSettings:
         return self.active_settings.experimental_features
 
+    @property
+    def enterprise_features(self) -> list[EnterpriseFeatures]:
+        """Returns a list of enterprise features that are enabled based on the settings."""
+        return self.active_settings.enterprise_features
+
 
 class Settings(BaseSettings):
     """Main Settings Class for the project."""
@@ -890,16 +935,22 @@ class Settings(BaseSettings):
     logging: LoggingSettings = LoggingSettings()
     analytics: AnalyticsSettings = AnalyticsSettings()
     initial: InitialSettings = InitialSettings()
+    policy: PolicySettings = PolicySettings()
     security: SecuritySettings = SecuritySettings()
     storage: StorageSettings = StorageSettings()
     trace: TraceSettings = TraceSettings()
     experimental_features: ExperimentalFeaturesSettings = ExperimentalFeaturesSettings()
 
+    @property
+    def enterprise_features(self) -> list[EnterpriseFeatures]:
+        """Returns a list of enterprise features that are enabled based on the settings."""
+        return self.policy.enterprise_features
+
 
 def load(config_file_name: Path | str = "infrahub.toml", config_data: dict[str, Any] | None = None) -> Settings:
     """Load configuration.
 
-    Configuration is loaded from a config file in toml format that contains the settings,
+    Configuration is loaded from a configuration file in toml format that contains the settings,
     or from a dictionary of those settings passed in as "config_data"
     """
     config_file = Path(config_file_name)
