@@ -21,7 +21,7 @@ class EnrichedDiffConflictUpdateQuery(Query):
         self.conflict_id = conflict_id
         self.selection = selection
 
-    async def query_init(self, db: InfrahubDatabase, **kwargs: Any) -> None:
+    async def query_init(self, db: InfrahubDatabase, **kwargs: Any) -> None:  # noqa: ARG002
         self.params = {"conflict_id": self.conflict_id, "selection": self.selection.value if self.selection else None}
         query = """
         MATCH (conflict:DiffConflict {uuid: $conflict_id})
