@@ -1,5 +1,5 @@
 from infrahub.permissions.backend import PermissionBackend
-from infrahub.permissions.globals import define_global_permission_from_branch
+from infrahub.permissions.globals import define_global_permission_from_branch, get_or_create_global_permission
 from infrahub.permissions.local_backend import LocalPermissionBackend
 from infrahub.permissions.manager import PermissionManager
 from infrahub.permissions.report import report_schema_permissions
@@ -12,5 +12,6 @@ __all__ = [
     "PermissionManager",
     "define_global_permission_from_branch",
     "get_global_permission_for_kind",
+    "get_or_create_global_permission",
     "report_schema_permissions",
 ]
